package org.example.controller;

import lombok.RequiredArgsConstructor;
import org.example.dto.PassingDTO;
import org.example.dto.UserDTO;
import org.example.service.PassingService;
import org.example.service.UserService;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("api/{username}")
@RequiredArgsConstructor
public class UserController {

    private final UserService userService;
    private final PassingService passingService;

    @GetMapping("/auth")
    public ResponseEntity<String> getUserByUsername(@PathVariable String username) {
        UserDTO userDTO = userService.getUserByUsername(username);
        return ResponseEntity.ok("данный логин существует - можно пользоваться приложением");
    }

    @GetMapping("/info")
    public ResponseEntity<UserDTO> getUserInfoByUsername(@PathVariable String username) {
        return ResponseEntity.ok(userService.getUserInfoByUsername(username));
    }

    @PatchMapping("/open")
    public ResponseEntity<String> patchUserByUsername(@PathVariable String username) {
        UserDTO userDTO = userService.patchUserByUsername(username);
        return ResponseEntity.ok("дверь открылась");
    }

    @GetMapping("/passing")
    public List<PassingDTO> getPassingByUsername(@PathVariable String username) {
        return passingService.getPassingByUsername(username);
    }

    @GetMapping("/passing/paginated")
    public ResponseEntity<Page<PassingDTO>> getAllPassingPaginated(
            @RequestParam(defaultValue = "0") int page,
            @RequestParam(defaultValue = "1") int size) {
        Pageable pageable = PageRequest.of(page, size);
        return ResponseEntity.ok(passingService.getAllPassingPaginated(pageable));
    }

//    @PostMapping("/passing/new")
//    public ResponseEntity<PassingDTO> createPassing(@RequestBody PassingDTO dto) {
//        return ResponseEntity.ok
//    }
}
