package org.example.service.impl;

import lombok.RequiredArgsConstructor;
import org.example.dto.UserDTO;
import org.example.entity.User;
import org.example.exception.UserNotFoundException;
import org.example.repository.CodeRepository;
import org.example.repository.UserRepository;
import org.example.service.UserService;
import org.example.util.UserMapper;
import org.springframework.stereotype.Service;

import java.util.Optional;

@Service
@RequiredArgsConstructor
public class UserServiceImpl implements UserService {
    private final UserRepository userRepository;
    private final CodeRepository codeRepository;
    @Override
    public UserDTO getUserByUsername(String username) {
        Optional<User> optionalUser = userRepository.findByUsername(username);

        if (optionalUser.isEmpty()) {
            throw new UserNotFoundException("логина не существует или неверный");
        }

        return UserMapper.convertToDto(optionalUser.get());
    }

    @Override
    public UserDTO getUserInfoByUsername(String username) {
        return userRepository.findByUsername(username).map(UserMapper::convertToDto).orElseThrow(() -> new UserNotFoundException("логина не существует или неверный"));
    }

    @Override
    public UserDTO patchUserByUsername(String username) {
        Optional<User> optionalUser = userRepository.findByUsername(username);

        if (optionalUser.isEmpty()) {
            throw new UserNotFoundException("логина не существует или неверный");
        }
        return UserMapper.convertToDto(optionalUser.get());
    }

}
